@@ -1,5 +1,4 @@
 from tempfile import NamedTemporaryFile
-from typing import Any, Dict
 
 from minio import Minio
 from vaex.dataframe import DataFrame
@@ -18,8 +17,8 @@ class ObjectStore:
             local_urls = ["127.0.0.1:9000", "localhost:9000"]
             return Minio(
                 config.minio_url,
-                access_key=config.minio_access_key,
-                secret_key=config.minio_secret_key,
+                access_key=config.current_user,
+                secret_key=config.token,
                 secure=False if config.minio_url in local_urls else True,
             )
         except Exception as e:
@@ -48,15 +47,3 @@ class ObjectStore:
                 object_name=object_name,
                 file_path=f.name,
             )
-
-    def get_fs_options(self) -> Dict[str, Any]:
-        return dict(
-            endpoint_override=config.minio_url,
-            scheme="https" if config.minio_url.startswith("https") else "http",
-            access_key=config.minio_access_key,
-            secret_key=config.minio_secret_key,
-            region=config.minio_region,
-        )
-
-
-object_store = ObjectStore()
