@@ -4,13 +4,15 @@ from typing import Dict, Optional
 
 from pydantic.types import UUID4
 
-from dataquality.clients import api_client
+from dataquality.clients.api import ApiClient
 from dataquality.core._config import config
 from dataquality.exceptions import GalileoException
 from dataquality.loggers import BaseGalileoLogger
 from dataquality.schemas.task_type import TaskType
 from dataquality.utils.name import random_name
 
+api_client = ApiClient()
+
 
 class _Init:
     def get_project_by_name_for_user(self, project_name: str) -> Dict:
