@@ -1,3 +1,4 @@
+import os
 from unittest import mock
 
 import pytest
@@ -16,10 +17,11 @@ from tests.utils.mock_request import (
 
 
 @mock.patch("requests.post", side_effect=mocked_create_project_run)
+@mock.patch("requests.get", side_effect=mocked_get_project_run)
 def test_init(*args) -> None:
     """Base case: Tests creating a new project and run"""
     config.token = "sometoken"
-    dataquality.init()
+    dataquality.init(task_type="text_classification")
     assert config.current_run_id
     assert config.current_project_id
 
@@ -30,7 +32,7 @@ def test_init_existing_project(*args) -> None:
     """Tests calling init passing in an existing project"""
     config.token = "sometoken"
     config.current_project_id = config.current_run_id = None
-    dataquality.init(project_name=EXISTING_PROJECT)
+    dataquality.init(task_type="text_classification", project_name=EXISTING_PROJECT)
     assert config.current_run_id
     assert config.current_project_id
 
@@ -41,7 +43,7 @@ def test_init_new_project(*args) -> None:
     """Tests calling init passing in a new project"""
     config.token = "sometoken"
     config.current_project_id = config.current_run_id = None
-    dataquality.init(project_name="new_proj")
+    dataquality.init(task_type="text_classification", project_name="new_proj")
     assert config.current_run_id
     assert config.current_project_id
 
@@ -52,7 +54,11 @@ def test_init_existing_project_new_run(*args) -> None:
     """Tests calling init with an existing project but a new run"""
     config.token = "sometoken"
     config.current_project_id = config.current_run_id = None
-    dataquality.init(project_name=EXISTING_PROJECT, run_name="new_run")
+    dataquality.init(
+        task_type="text_classification",
+        project_name=EXISTING_PROJECT,
+        run_name="new_run",
+    )
     assert config.current_run_id
     assert config.current_project_id
 
@@ -63,7 +69,11 @@ def test_init_existing_project_run(*args) -> None:
     """Tests calling init with an existing project and existing run"""
     config.token = "sometoken"
     config.current_project_id = config.current_run_id = None
-    dataquality.init(project_name=EXISTING_PROJECT, run_name=EXISTING_RUN)
+    dataquality.init(
+        task_type="text_classification",
+        project_name=EXISTING_PROJECT,
+        run_name=EXISTING_RUN,
+    )
     assert config.current_run_id
     assert config.current_project_id
 
@@ -74,7 +84,9 @@ def test_init_new_project_run(*args) -> None:
     """Tests calling init with a new project and new run"""
     config.token = "sometoken"
     config.current_project_id = config.current_run_id = None
-    dataquality.init(project_name="new_proj", run_name="new_run")
+    dataquality.init(
+        task_type="text_classification", project_name="new_proj", run_name="new_run"
+    )
     assert config.current_run_id
     assert config.current_project_id
 
@@ -83,7 +95,7 @@ def test_init_only_run(*args) -> None:
     """Tests calling init only passing in a run"""
     config.token = "sometoken"
     config.current_project_id = config.current_run_id = None
-    dataquality.init(run_name="a_run")
+    dataquality.init(task_type="text_classification", run_name="a_run")
     assert not config.current_run_id
     assert not config.current_project_id
 
@@ -92,6 +104,30 @@ def test_init_only_run(*args) -> None:
 def test_init_no_login(*args) -> None:
     config.token = None
     with pytest.raises(GalileoException):
-        dataquality.init()
+        dataquality.init(task_type="text_classification")
     with pytest.raises(GalileoException):
-        dataquality.init(project_name=EXISTING_PROJECT)
+        dataquality.init(task_type="text_classification", project_name=EXISTING_PROJECT)
+
+
+@mock.patch("requests.get", side_effect=mocked_get_project_run)
+def test_init_bad_task(*args) -> None:
+    config.token = "sometoken"
+    with pytest.raises(GalileoException):
+        dataquality.init(task_type="not_text_classification")
+
+
+@mock.patch("requests.post", side_effect=mocked_create_project_run)
+@mock.patch("requests.get", side_effect=mocked_get_project_run)
+def test_reconfigure(*args) -> None:
+    config.token = "sometoken"
+    dataquality.init(task_type="text_classification")
+    assert config.current_run_id
+    assert config.current_project_id
+    old_url = config.minio_url
+    test_url = f"{old_url}_TEST"
+    os.environ["GALILEO_MINIO_URL"] = test_url
+    dataquality.configure()
+    assert dataquality.config.minio_url == config.minio_url == test_url
+    os.environ["GALILEO_MINIO_URL"] = old_url
+    dataquality.configure()
+    assert dataquality.config.minio_url == config.minio_url == old_url
